// --------------------------------------------------------------------------------------------DistributionOverStates0p
// This code produces the content of Table A5 (Online Appendix),
// that is, it computes the distribution over observable states (earning / welfare participation) .
// 
// This code has five parts:
// 	PART 1: sets parameters/ preferences which determine which Table to reproduce, which part of the code to run etc.
// 	PART 2: works on the data in entry to prepare it for PART 3
// 	PART 3: computes the distribution over observable states
// 	PART 4: computes the SEs by bootstrapping 
// 	PART 5: outputs to .txt file the distribution over observable states & the boostrapped data for processing in Matlab
// 
// This code take as inputs:
// 	1. pre-generated MDRC data
// 	2. pre-generated data sets of welfare policy rules 
// 
// This code outputs:
// 	1. A .txt file with the distribution over observable states & the boostrapped data for processing in Matlab
// 	2. A .log file with the output appearing on STATA's Results window.
// 
// Last Revision: 08/31/2015
//-------------------------------------------------------------------------------------------------------------------------------
args jf_dtain rules_dtain 




capture program drop DistributionOverStates0p
capture program define DistributionOverStates0p

	args jf_dtain rules_dtain 


	//------------------------------------------------ PART 1  ------------------------------------------------------
	// Select which postRA quarters you want to use (among those in the reshaped data)
	// Store in a global variable the list of variables describing the distribution over states.
	// Name the file in output.
	//---------------------------------------------------------------------------------------------------------------
		local fq = 1
		local lq = 7	
		global marginalvars "p0N p1N p2N p0P p1P p2P"
		local whatwedo = "TableA5"
		local logfileout	"$oJF/`whatwedo'.log"		// for keeping track
		
		
			

		
		
		
	//------------------------------------------------ PART 2  ------------------------------------------------------
	// Bring in Policy Parameters
	//---------------------------------------------------------------------------------------------------------------	
		matrix drop _all
		qui use "`rules_dtain'", clear
		keep  F3 year size
		rename F3 F3_
		reshape wide  F3, i(year) j(size)
		sort year 
		qui save "$ddJF/JF_ADFCrules_temp.dta", replace
		
		
		
		
		
		
	//------------------------------------------------ PART 3  ------------------------------------------------------
	// Create the data set
	//---------------------------------------------------------------------------------------------------------------
		qui use ernq0-ernq7 afdconq1-afdconq7 id e ///
				earnq  afdcon_nminq afdcon afdcamt year quarter month applcant ///
				$pscorevars $mdrcvars  ///
				kidcount using "`jf_dtain'" if quarter>=-7&quarter<=`lq' & kidcount~=., clear	
		sort id quarter month


		//----------------------------------------------------------------
		// whether in state 0p in PQ1 (missing if not in this state because not on/off all quarters)
		//----------------------------------------------------------------
		qui gen pqstate0p = 0 if (afdcon_nminq==0|afdcon_nminq==3) 
		qui replace pqstate0p = 1 if afdcon_nminq==3
		qui replace pqstate0p = 0 if pqstate0p==1&earnq~=0 // working
		qui replace pqstate0p = . if quarter~=-1
		rename pqstate0p temp
		qui by id: egen pqstate0p = max(temp) // spread across all time periods
		drop temp

		//----------------------------------------------------------------
		qui drop if quarter<`fq'
		

		//---------------------------------------------------------------------------------------------- 
		// AU size which is needed in order to associate the correct FPL (it must be the same for each quarter!!!!)
		//--------------------------------------------------------------------------------------	 
		qui gen size = kidcount +1 if kidcount==1|kidcount==2|kidcount==3
		qui replace size = 2 if kidcount==0
		
		//---------------------------------------------------
		// Merge in policy parameters
		//---------------------------------------------------
		sort year
		qui merge m:1 year using  "$ddJF/JF_ADFCrules_temp.dta"
		qui drop if _m~=3 // drop years for which you do not have the rules
		drop _m
		
		//----------------------------------------------------------------------------------------------
		// For each TREATMENT & CONTROL observation determine in which bin the FPL -for recipients- on quartely basis belongs to
		// the variable is called Cbin because it refers to the point denoted by C. in the picture of the budget set under JF-TANF
		//----------------------------------------------------------------------------------------------
		local maxs = 10
		local maxy = 1999 // enough to go to Q7 post RA
		qui gen Cbin = .
		forvalues y=1996(1)`maxy' {
			forvalues s=1(1)`maxs' {
				//-----------------------------------------
				// size to use for the FPL = `s'+1 means the next size up
				//-----------------------------------------
				local ss = `s' +1
				qui gen F_`ss' = F3_`ss'
				//-----------------------------------------
				// identify the number of the bin to which the 
				// quartely FPL for an AU of this size in this calendar year
				//------------------------------------------
				qui replace Cbin =  0 if size==`s'&year==`y'&3*F_`ss'==0 // for completeness, will never be active
				qui replace Cbin =  1 if size==`s'&year==`y'&3*F_`ss'>0&3*F_`ss'<150 // for completeness
				qui replace Cbin =  round(3*F_`ss',100) if size==`s'&year==`y'&Cbin==.
				drop F_`ss'
			}
		}
		assert Cbin~=. if size<=`maxs'&year<=`maxy'		
		//---------------------------------------------------
		// Assign everybody to an income bin {0,1,2}
		// where 0= q. earning are exactly zero
		// where 1= q. earning are strictly positive and equal to FPL or below where FPL 
		//             is the one used for an AU of this size under JF-TANF in Q1-Q7
		// where 2= q. earning are strictly above FPL 
		//---------------------------------------------------		
		qui gen ebin = 0 if earnq==0
		qui replace ebin = 1 if earnq<=Cbin	& earnq~=0
		qui replace ebin = 2 if earnq>Cbin	& earnq~=.

		//---------------------------------------------------
		// Assign everybody to a participation bin (welfare participation)
		// Given the income bin and participation, fill the dummies
		//---------------------------------------------------
		qui gen included = 0
		qui gen partic = afdcon_nminq

		qui replace included = (afdcon_nminq==0|afdcon_nminq==3)
		qui replace partic = 1 if afdcon_nminq==3
		qui replace partic = . if included==0
		
		qui gen p0N = (ebin==0&partic==0)
		qui gen p1N = (ebin==1&partic==0)
		qui gen p2N = (ebin==2&partic==0)
		qui gen p0P = (ebin==0&partic==1)
		qui gen p1P = (ebin==1&partic==1)
		qui gen p2P = (ebin==2&partic==1)
		foreach var of varlist $marginalvars {
			qui replace `var' = 0 if included==0
		}

		//---------------------------------------------------
		// Go to unit x quarter then reshape wide so that for each unit the quaters are in cols
		//---------------------------------------------------
		qui gen nn = .
		qui bys id quarter: replace nn = _n
		qui drop if nn~=1 // wlog we drop 2 of the 3 months in the quarter 
		keep ernq0-ernq7 afdconq1-afdconq7 id e ///
				quarter applcant  included $pscorevars $mdrcvars $marginalvars pqstate0p
		/* OLD REDUNDANT
		keep ernq0-ernq16 transq1-transq16 totq1-totq16 afdconq1-afdconq16 id e ///
		quarter applcant  included $pscorevars $mdrcvars $marginalvars pqstate0p
		*/
		qui reshape wide $marginalvars included, i(id) j(quarter)
		qui keep if pqstate0p==1
		tempfile file1
		qui save "`file1'", replace






	//------------------------------------------------ PART 4  ------------------------------------------------------
	// Create the Table
	//---------------------------------------------------------------------------------------------------------------
	capture log close
	log using "`logfileout'", replace
	local colnames = ""
	forvalues myq=`fq'(1)`lq' { // loop over quarters 1 to 7
		local colnames = "`colnames' `myq'"
		qui use  "`file1'", clear
		forvalues q=`fq'(1)`lq' {
			if `q'~=`myq' {
				drop p0N`q' p1N`q' p2N`q' p0P`q' p1P`q' p2P`q'
			}
		}
		//---------------------------------------------------
		//Now executing code necessary for pscore model and 
		// inverse propensity score weighting (IPW) stuff 
		//---------------------------------------------------
		qui logit e $pscorevars, asis
		qui predict double pscore                                      
		qui gen double pscorewt = e/pscore + (1-e)/(1-pscore)
		//---------------------------------------------------
		// Reshape long to have a data set with quartely marginal probabilities
		//---------------------------------------------------
		local nmv = 6
		keep p0N* p1N* p2N* p0P* p1P* p2P*  pscorewt e id included* 
		qui reshape long p0N@ p1N@ p2N@ p0P@ p1P@ p2P@ included@, i(id) j(q)		
		//-----------------------------------------------------------------------------------
		// Adjusted distribution (using pscore).
		// Account for the fact that you may exclude some quarters from the computations
		// estimated probability - among controls - of being in subcollection x (weighted using the prop score)
		// estimated probability - among treatment - of being in subcollection x (weighted using the prop score)
		//-----------------------------------------------------------------------------------
		qui sum included 	[aw=pscorewt]	if e==0
		qui gen p = r(mean) 	if e==0
		qui sum included 	[aw=pscorewt]	if e==1
		qui replace p = r(mean) if e==1
		// E[YD|T]/E[D|T] where D=1 if in x subcollection, T=1 if JF and Y=p's
		foreach var of varlist $marginalvars {
			qui replace `var' = `var'/p
		}
		qui meandifs $marginalvars [aw=pscorewt], by(e) 
		matrix define Tab = r(table) // store results	
		local l = (2-1)*`nmv'+1
		local u = 2*`nmv'
		matrix define Tab`q' = Tab[1,`l'..`u']'
		qui sum $marginalvars if e==0
		local nobsC = r(N)
		if `myq'==1 {
			di ""
			di ""
			di "The number of C-cases used is " `nobsC'
			matrix define `whatwedo' = Tab`q'
		}
		else {
			matrix define `whatwedo' = (`whatwedo',Tab`q')
		}
	}
	di ""
	di ""
	di "======================================== `whatwedo' "
	matrix colnames `whatwedo' = `colnames'
	matrix list `whatwedo', noheader format(%6.3f)
	log close
	erase  "$ddJF/JF_ADFCrules_temp.dta"
end 




//------------------------------------------------ PART 5  ------------------------------------------------------
// Create the Table
//---------------------------------------------------------------------------------------------------------------
DistributionOverStates0p "`jf_dtain'" "`rules_dtain'"






